Crate streamling_state

Crate streamling_state 

Modules

in_memory
postgres
sqlite

Structs

StateBackendError
StateKey
Type for the keys used in the state backend. For simplicity, it’s assumed that all state backends will use the same key format (strings). If it were to change, a new generic type could be added, similar to the V type parameter.

Enums

StateBackendErrorKind
StateBackendFactories

Traits

StateOperatorBackend
StateOperatorBackendFactory