StateKey

Struct StateKey 

pub struct StateKey(pub String);
Type for the keys used in the state backend. For simplicity, it’s assumed that all state backends will use the same key format (strings). If it were to change, a new generic type could be added, similar to the V type parameter.

Tuple Fields

0: String